##########################################################################
# "Low migratory connectivity is common in long-distance migrant birds" 
# Finch, T, Butler, S, Franco, A & Cresswell, W. 
# VERSION 17-12-2016
# See readme.txt for full description of data package

# This script loads, tidies and merges data files "data1_afropal.csv" and "data2_neotrop.csv" 
##########################################################################

# INSTALL PACKAGES --------------------------------------------------------
install.packages("intall.load"); library("install.load")
install_load(
          # Tidying
          "dplyr",
          "readr",
          
          # Plotting
          "ggplot2",
          "cowplot",
          "viridis",
          
          # Spatial
          "raster",
          "sp",
          "rgdal",
          "geosphere",
          "rgeos",
          "ecodist",
          
          # Stats, etc.
          "lme4",
          "MuMIn",
          "influence.ME",
          "AICcmodavg"
          )

# CUSTOM FUNCTIONS ---------------------------------------------------------
# Mean inter-individual distance
meanDist <- function(lon, lat){
          mean(lower(distm(cbind(lon, lat), fun = distHaversine)))
}

# Mantel correlation score
# r value
mantelCor <- function(lon1, lat1, lon2, lat2){
          out <- mantel(lower(distm(cbind(lon1, lat1), fun = distHaversine)) ~
                        lower(distm(cbind(lon2, lat2), fun = distHaversine)))
          return(out[c(1)])
}

# p value
mantelCorP <- function(lon1, lat1, lon2, lat2){
          out <- mantel(lower(distm(cbind(lon1, lat1), fun = distHaversine)) ~
                        lower(distm(cbind(lon2, lat2), fun = distHaversine)))
          return(out[c(4)])
}

# Center (without scaling)
center <- function(x){scale(x, scale = F, center = T)}

# Custom ggplot theme
theme_tom <- function(base_size = 8, base_family = "") {
          # Starts with theme_grey and then modify some parts
          theme_grey(base_size = base_size, base_family = base_family) %+replace%
                    theme(
                              # theme_bw() stuff:
                              legend.key        = element_rect(colour = "grey80"),
                              panel.background  = element_rect(fill = "white", colour = NA),
                              panel.border      = element_rect(fill = NA, colour = "grey50"),
                              panel.grid.major  = element_line(colour = "grey90", size = 0.2),
                              panel.grid.minor  = element_line(colour = "grey98", size = 0.5),
                              strip.background  = element_rect(fill = "grey80", colour = "grey50", size = 0.2),
                              # Custom stuff
                              axis.text         = element_text(size = 8),
                              axis.ticks        = element_line(colour = "black", size = 0.2),
                              plot.title        = element_text(size = 12, hjust = 0, face = "bold", margin=margin(b = 3, unit = "pt")),
                              legend.text       = element_text(size = 7),
                              legend.key.size   = unit(3, "mm"),
                              strip.text        = element_text(size = 8),
                              legend.background = element_rect(colour = 1, fill = scales::alpha("white", 0.9), size = 0.25)
                    )
}

# READ IN DATA ---------------------------------------------------------------
# Read in data
data <- read_csv("data.csv")

# Read world countries shapefile
world.shp <- readOGR("worldmap.geojson", "OGRGeoJSON", verbose = F)

# Crop & fortify (i.e. convert to data.frame) for plotting with ggplot2
pal.shp <- world.shp %>% crop(., extent(-80, 155, -40, 90)) %>% fortify
neo.shp <- world.shp %>% crop(., extent(-180, -15, -60, 90)) %>% fortify

# TIDY DATA ---------------------------------------------------------
# Fix thrush nightingale - set main winter site as final one
data[data$species == "thrush nightingale",]$wlat1 <- data[data$species == "thrush nightingale",]$wlat3
data[data$species == "thrush nightingale",]$wlon1 <- data[data$species == "thrush nightingale",]$wlon3

data <- data %>% 
          # Format species - no spaces or apostrophes 
          mutate(species = gsub(" ", ".", species)) %>% 
          mutate(species = gsub("'", "", species)) %>% 
          
          # Set unknown age to -1
          mutate(age = ifelse(is.na(age), -1, age)) %>% 
          
          # Exclude juveniles
          filter(age != 0) %>% 
          
          # Exclude if outside breeding range (afro only)
          filter((system == "afro" & blon >= -20 & blon <= 65) | (system == "neo")) %>% 
          
          # Exclude if outside winter range (afro and neo)
          filter((system == "afro" & wlat1 <= 20 & wlon1 <= 65) | (system == "neo" & wlat1 <= 30)) %>% 
          
          # Exclude if tagged overwinter
          filter(sampledat == 1) %>% 
          
          # Exclude northern wheatear from neo (winters in afro)
          filter(!(system == "neo" & species == "northern.wheatear")) %>% 
          
          # Tidy columns
          dplyr:::select(-study, -method, -sampledat, -wlat2:-notes)


# MODIFY DATA ----------------------------------------------------------------------
data <- data %>% 
          # Create unique code per population per species
          mutate(popid = paste(species, popunique, system, sep = ".")) %>% 
          
          # Create unique code per species
          mutate(species2 = paste(species, system, sep = ".")) %>% 
          
          # Count individuals per species
          group_by(system, species) %>% 
          mutate(nspp = length(species)) %>%
          
          # Exclude single individual species
          filter(nspp > 1) %>% 
          
          # Count individuals per population
          group_by(popid) %>% 
          mutate(nind = length(popid)) %>% 
          
          # Count populations per species
          group_by(system, species) %>% 
          mutate(npop = length(unique(popid))) %>%
          ungroup() %>% 
          
          # System to numeric
          mutate(system = ifelse(system == "afro", "1", "2"))

# AGGREGATE DATA BY POPULATION ----------------------------------------------------
data.pop <- data %>% 
          # Exlude single individual populations
          filter(nind > 1) %>% 
          group_by(popid) %>% 
          summarise('species' = first(species),
                    'species2' = first(species2),
                    'family' = first(family),
                    'order' = first(order),
                    'state' = first(state),
                    'n' = length(popid),
                    # Mean breeding longitude & lat
                    'b.lon' = mean(blon),
                    'b.lat' = mean(blat),  
                    # Longitudinal range of breeding sites 
                    'b.londif' = diff(range(blon)), 
                    # Max distance between breeding sites
                    'b.maxdist' = (max(lower(distm(cbind(blon, blat), fun = distHaversine))))/1000,
                    # Mean distance between breeding sites
                    'b.meandist' = (meanDist(blon, blat))/1000, 
                    # Mean winter longitude & lat
                    'w.lon' = mean(wlon1), 
                    'w.lat' = mean(wlat1),
                    # Longitudinal range of winter sites
                    'w.londif' = diff(range(wlon1)), 
                    # Max distance between winter sites
                    'w.maxdist' = (max(lower(distm(cbind(wlon1, wlat1), fun = distHaversine))))/1000,
                    # Mean distance between winter sites
                    'w.meandist' = (meanDist(wlon1, wlat1))/1000, 
                    # Distance between mean breding and winter site
                    'mig.distance' = (distHaversine(cbind(mean(blon), mean(blat)), cbind(mean(wlon1), mean(wlat1))))/1000,
                    # Sytem (2 = america, 1 = europe)
                    'system' = first(system),
                    # Zone (1 = northern, 2 = southern)
                    'zone' = ifelse((system == "1" & w.lat <= 4) | (system == "2" & w.lat <= 12), "2", "1")) %>%
          # Relative system specific longitude
          group_by(system) %>% 
          mutate(b.lon.rel = as.numeric(center(b.lon))) %>% 
          mutate(w.lon.rel = as.numeric(center(w.lon))) %>% 
          ungroup()
          
# AGGREGATE DATA BY SPECIES ----------------------------------------------------
data.spp <- data %>% 
          # Exclude single population species
          filter(npop > 1) %>% 
          group_by(species2) %>% 
          summarise('species' = first(species),
                    'npop' = length(unique(popid)),
                    'nind' = length(popid),
                    'family' = first(family),
                    'order' = first(order),
                    'b.lon' = mean(blon),
                    'b.lat' = mean(blat),
                    'b.londif' = diff(range(blon)),
                    'b.maxdist' = (max(lower(distm(cbind(blon, blat), fun = distHaversine))))/1000,
                    'b.meandist' = (meanDist(blon, blat))/1000,
                    'w.lon' = mean(wlon1),
                    'w.lat' = mean(wlat1),
                    'w.londif' = diff(range(wlon1)),
                    'w.maxdist' = (max(lower(distm(cbind(wlon1, wlat1), fun = distHaversine))))/1000,
                    'w.meandist' = (meanDist(wlon1, wlat1))/1000,
                    'mig.distance' = (distHaversine(cbind(mean(blon), mean(blat)), cbind(mean(wlon1), mean(wlat1))))/1000,
                    # Correlation coefficient between breeding and winter distance matrices
                    'mantelR' = mantelCor(blon, blat, wlon1, wlat1),
                    # Correlation p-value between breeding winter distance matrices
                    'mantelP' = mantelCorP(blon, blat, wlon1, wlat1),
                    'system' = first(system),
                    'zone' = ifelse((system == "1" & w.lat <= 4) | (system == "2" & w.lat <= 12), "2", "1")) %>% 
          # Relative system specific longitude
          group_by(system) %>% 
          mutate(b.lon.rel = as.numeric(center(b.lon))) %>% 
          mutate(w.lon.rel = as.numeric(center(w.lon))) %>% 
          ungroup() %>%
          # Merge with mean pop- spread
          inner_join(., summarise(group_by(data.pop, species2), mean.w.meandist = mean(w.meandist)))

