##########################################################################
# "Low migratory connectivity is common in long-distance migrant birds" 
# Finch, T, Butler, S, Franco, A & Cresswell, W. 
# VERSION 17-12-2016
# See readme.txt for full description of data package

# This script extracts connectivity metrics from raw data, fits models described in main text, and extracts fitted values for plotting
##########################################################################

# SOURCE script1 --------------------------------------------------------
source("script1_data_processing.R")

# Model 1 ------------------------------------------------------------------
#################################################
# Response = maximum distance between individuals from the same breeding population overwinter (w.maxdist)
# Independent variable = n (linear, quadratic, logarithm)
# Random intercept = species
#################################################
## Model
data.pop <- data.pop %>% mutate(ln = log(n), n2 = n ^ 2)
# Fit models
mod1.1 <- lmer(w.maxdist ~ n      + (1|species), data = data.pop, REML = F, na.action = "na.fail")
mod1.2 <- lmer(w.maxdist ~ n + n2 + (1|species), data = data.pop, REML = F, na.action = "na.fail")
mod1.3 <- lmer(w.maxdist ~ ln     + (1|species), data = data.pop, REML = F, na.action = "na.fail")
mod1.4 <- lmer(w.maxdist ~ 1      + (1|species), data = data.pop, REML = F, na.action = "na.fail")
# AICc model selection
model.sel(list(mod1.1,
               mod1.2,
               mod1.3, # Best
               mod1.4))

summary(mod1.3)
r.squaredGLMM(mod1.3)

## Predictions - for plotting
fit1 <- data.frame(ln = log(c(seq(1, 50, 1))))
fit1 <- cbind(fit1, predictSE(mod = mod1.3, newdata = fit1))

## Check cook's distance (lme4 and influence.ME)
cooks <- cooks.distance(influence(mod1.3a, obs = TRUE))
mod1.3b <- lmer(w.maxdist ~ ln + (1|species), subset(data.pop, cooks < quantile(cooks, 0.95)))
plot(predict(mod1.3 , newdata = fit1, re.form = NA),
     predict(mod1.3b, newdata = fit1, re.form = NA), type = 'l')
          
# Model 2 ----------------------------------------
#################################################
# Response = mean over winter distance between individuals from the same breeding population 
# Independent variable = migration distance, zone, system, breeding longitude, interactions
# Random intercept = species
#################################################

## Model
# Full model
library(nlme)
mod2 <- lmer(w.meandist ~ b.lon.rel * zone * system + (1|species), data = data.pop, REML = F, na.action = "na.fail")
# AICc model selection
dredge(mod2) # Full model is best

## Predictions - for plotting
fit2 <- data.frame('b.lon.rel' = c(seq(min(subset(data.pop, system == "1" & zone == "1")$b.lon.rel), max(subset(data.pop, system == "1" & zone == "1")$b.lon.rel), length.out = 10),
                                   seq(min(subset(data.pop, system == "1" & zone == "2")$b.lon.rel), max(subset(data.pop, system == "1" & zone == "2")$b.lon.rel), length.out = 10),
                                   seq(min(subset(data.pop, system == "2" & zone == "1")$b.lon.rel), max(subset(data.pop, system == "2" & zone == "1")$b.lon.rel), length.out = 10),
                                   seq(min(subset(data.pop, system == "2" & zone == "2")$b.lon.rel), max(subset(data.pop, system == "2" & zone == "2")$b.lon.rel), length.out = 10)),
                   'zone' = rep(rep(c("1", "2"), each = 10), 2),
                   'system' = rep(c("1", "2"), each = 20))
# predictSE fails (Error: object 'contr' not found) with lme4 object - but works with lme - predictions are identical, but convert to lme to get SE
mod2.1 <- lme(w.meandist ~ b.lon.rel * zone * system, random = ~1|species, data = data.pop, method = "ML", na.action = "na.fail")
fit2 <- cbind(fit2, predictSE(mod = mod2.1, newdata = fit2))

## Check cook's distance (lme4 and influence.ME)
mod2a <- lmer(w.meandist ~ zone * b.lon.rel * system + (1|species), data.pop)
cooks <- cooks.distance(influence(mod2a, obs = TRUE))
mod2b <- lmer(w.meandist ~ zone * b.lon.rel * system + (1|species), subset(data.pop, cooks < quantile(cooks, 0.95)))
plot(predict(mod2a, newdata = fit2, re.form = NA),
     predict(mod2b, newdata = fit2, re.form = NA))

## With mig distance or breeding lat
mod2a <- lmer(w.meandist ~ mig.distance * zone + zone * b.lon.rel * system + (1|species), data = data.pop, REML = F, na.action = "na.fail")
mod2b <- lmer(w.meandist ~ b.lat        * zone + zone * b.lon.rel * system + (1|species), data = data.pop, REML = F, na.action = "na.fail")
dredge(mod2a) # Mig dist not in top model
dredge(mod2b) # Breeding lat not in top model

## Phylogeny - nest species effect in family and / or order
# With family or order 
mod2.fam <- lmer(w.meandist ~ zone * b.lon.rel * system + (1|family/species), data.pop, REML = F, na.action = "na.fail")
mod2.orf <- lmer(w.meandist ~ zone * b.lon.rel * system + (1|order/family/species), data.pop, REML = F, na.action = "na.fail")
mod2.ord <- lmer(w.meandist ~ zone * b.lon.rel * system + (1|order/species), data.pop, REML = F, na.action = "na.fail")
# Interpret R2m and R2c
r.squaredGLMM(mod2.fam)
r.squaredGLMM(mod2.orf)
r.squaredGLMM(mod2.ord)
# No improvement compared to original model
r.squaredGLMM(mod2.1)

# Model 3 ----------------------------------------
#################################################
# Response = mantel correlation coefficient
# Independent variables = b.meandist,  w.meandist, w.meandist ^ 2,  mean.w.meandist
#################################################

## Model
# Full model
mod3 <- lm(mantelR ~ b.meandist + w.meandist + I(w.meandist^2) + mean.w.meandist, data = data.spp, na.action = "na.fail")
# AICc model selection
dredge(mod3) # Model without b.meandist is best 
mod3a <- lm(mantelR ~ w.meandist + I(w.meandist^2) + mean.w.meandist, data = data.spp, na.action = "na.fail")

## Predictions - for plotting
fit3 <- expand.grid('w.meandist' = seq(min(data.spp$w.meandist), max(data.spp$w.meandist), length.out = 200),
                    'mean.w.meandist' = quantile(data.spp$mean.w.meandist, c(0.1, 0.9)))
fit3 <- data.frame(fit3, predict(object = mod3.1, newdata = fit3, se.fit = T))

## Check cook's distance 
cooks <- cooks.distance(mod3a)
mod3b <- lm(mantelR ~ w.meandist + I(w.meandist^2) + mean.w.meandist, data = subset(data.spp, cooks < quantile(cooks, 0.95)), na.action = "na.fail")
plot(predict(mod3a, newdata = fit3),
     predict(mod3b, newdata = fit3))

## Phylogeny - nest species effect in family and / or order
# With family or order 
mod3.1 <- lmer(mantelR ~ w.meandist + I(w.meandist^2) + mean.w.meandist + (1|family), data = data.spp, na.action = "na.fail", REML = F)
mod3.2 <- lmer(mantelR ~ w.meandist + I(w.meandist^2) + mean.w.meandist + (1|order), data = data.spp, na.action = "na.fail", REML = F)
mod3.3 <- lmer(mantelR ~ w.meandist + I(w.meandist^2) + mean.w.meandist + (1|order/family), data = data.spp, na.action = "na.fail", REML = F)

r.squaredGLMM(mod3a)
r.squaredGLMM(mod3.1)
r.squaredGLMM(mod3.2)
r.squaredGLMM(mod3.3)

# Sample sizes ------------------------------------------------------------
# Palearctic
length(unique(subset(data.pop, system == 1)$popid)) # 50 populations
length(unique(subset(data.pop, system == 1)$species)) # 29 species
mean(subset(data.pop, system == 1)$n)
range(subset(data.pop, system == 1)$n)
sum(subset(data.pop, system == 1)$n)

# Neotropic
length(unique(subset(data.pop, system == 2)$popid)) # 48 populations
length(unique(subset(data.pop, system == 2)$species)) # 16 species
mean(subset(data.pop, system == 2)$n)
range(subset(data.pop, system == 2)$n)
sum(subset(data.pop, system == 2)$n)

# Palearctic
length(unique(subset(data.spp, system == 1)$species2))
mean (subset(data.spp, system == 1)$npop)
range(subset(data.spp, system == 1)$npop)
mean( subset(data.spp, system == 1)$nind / subset(data.spp, system == 1)$npop)
range(subset(data.spp, system == 1)$nind / subset(data.spp, system == 1)$npop)

# Neotropic
length(unique(subset(data.spp, system == 2)$species2))
mean (subset(data.spp, system == 2)$npop)
range(subset(data.spp, system == 2)$npop)
mean( subset(data.spp, system == 2)$nind / subset(data.spp, system == 2)$npop)
range(subset(data.spp, system == 2)$nind / subset(allsp, system == 2)$npop)

