##########################################################################
# "Low migratory connectivity is common in long-distance migrant birds" 
# Finch, T, Butler, S, Franco, A & Cresswell, W. 
# VERSION 17-12-2016
# See readme.txt for full description of data package

# This script creates plots of data and fitted relationships and saves Fig S1 and Figs 1-4
##########################################################################

# SOURCE script2 --------------------------------------------------------
source("script2_main_analysis.R")

# FIGURE S1 ---------------------------------------------------------------
## Sample size ~ maximum population spread
figS1 <- ggplot(data = data.pop) + geom_point(aes(x = n, y = w.maxdist), size = 1, alpha = 0.8) + 
          geom_line(data = fit1, aes(x = exp(ln), y = fit), size = 1) +
          geom_ribbon(data = fit1, aes(x = exp(ln), ymin = (fit - 1 * se.fit), ymax = (fit + 1 * se.fit)), alpha = 0.3) + 
          labs(x = "Number of individuals sampled", y = "Maximum inter-individual distance (km)") + 
          theme_tom() 
figS1
# Save
# ggsave("plots/n_range.png", figS1, width = unit(70, "mm"), height = unit(70, "mm"), dpi = 1000, units = "mm")

# FIGURE 2 ---------------------------------------------------------------
## Map of raw data
fig2a <- ggplot() + geom_polygon(data = neo.shp, aes(x = long, y = lat, group = group), fill = "black", colour = "black", size = 0.1) +
          coord_map("mercator", xlim = c(-132, -37), ylim = c(-45, 65)) +
          theme_bw(7) + theme(axis.text = element_blank(), axis.ticks = element_blank(), panel.background = element_rect(fill = "gray25"), panel.grid = element_blank()) +
          labs(x = NULL, y = NULL) +
          geom_segment(data = subset(data, system == 2), aes(x = blon, y = blat, xend = wlon1, yend = wlat1), alpha = 0.2, colour = "gray90", size = 0.3)
fig2b <- ggplot() + geom_polygon(data = pal.shp, aes(x = long, y = lat, group = group), fill = "black", colour = "black", size = 0.1) +
          coord_map("mercator", xlim = c(-25, 70), ylim = c(-45, 65)) +
          theme_bw(7) + theme(axis.text = element_blank(), axis.ticks = element_blank(), panel.background = element_rect(fill = "gray25"), panel.grid = element_blank()) +
          labs(x = NULL, y = NULL) +
          geom_segment(data = subset(data, system == 1), aes(x = blon, y = blat, xend = wlon1, yend = wlat1), alpha = 0.2, colour = "gray90", size = 0.3)
fig2 <- plot_grid(fig2a, fig2b)
fig2
# Save
# ggsave("plots/fig2.png", fig2, width = unit(150, "mm"), height = unit(110, "mm"), dpi = 1000, units = "mm")

# FIGURE 3 ----------------------------------------------------------------
## Histogram of mean population spread
fig3 <- ggplot(data = data.pop) + geom_histogram(aes(x = w.meandist), binwidth = 250, colour = 1, boundary = 0, alpha = 0.5) + 
          labs(x = "Population spread\n(mean inter-individual distance; km)", y = "Number of populations") + 
          scale_y_continuous(breaks = seq(0, 30, by = 5)) + 
          theme_tom()
fig3
# Save
# ggsave("plots/fig3.png", fig3, width = unit(70, "mm"), height = unit(70, "mm"), dpi = 1000, units = "mm")

# FIGURE 4 ----------------------------------------------------------------
## Results of Mantel test and migratory mixing anaylsis
# Tidy data for plotting
data.spp <- data.spp %>% 
          arrange(mantelR) %>% 
          mutate(rank = rank(mantelR)) %>% 
          mutate(sig = ifelse(mantelP >= 0.05, "0", "1")) %>% 
          mutate(species = gsub("\\.", " ", species))

# Labels for plotting
fit3$mean.w.meandist.lab <- factor(fit3$mean.w.meandist)
levels(fit3$mean.w.meandist.lab) <- c("Low population spread", "High population spread")
data.spp$mean.w.meandist.lab <- as.factor(data.spp$mean.w.meandist > mean(data.spp$mean.w.meandist))
levels(data.spp$mean.w.meandist.lab) <- c("Low population spread", "High population spread")

# Colours for plotting
himixcol <- "#843C0C"
lomixcol <- "#F8CBAD"
hisspspreadcol <- "#385723"
losspspreadcol <- "#C5E0B4"

fig4a <- ggplot(data.spp, aes(x = rank, y = mantelR)) + geom_line(size = 0.5, alpha = 0.5) +
          geom_point(aes(shape = system, alpha = sig), fill = 1, col = 1, stroke = 0.2) +
          geom_text(aes(y = mantelR + c(rep(0.05, nrow(data.spp)-7), rep(-0.05, 7)), label = species), size = 1.5, angle = 90, hjust = c(rep(0, nrow(data.spp)-7), rep(1, 7))) + 
          scale_alpha_manual(values = c(0.4, 0.8)) + 
          guides(fill = F, shape = F, alpha = F) + 
          coord_cartesian(ylim = c(-0.5, 1)) + 
          labs(x = "Species", y = "Mantel correlation coefficient") + 
          theme_tom() + theme(aspect.ratio = 1, axis.text.x = element_blank())

fig4b <- ggplot() + geom_point(data = data.spp, aes(x = w.meandist, y = mantelR, shape = system, colour = mean.w.meandist.lab, alpha = 0.9), stroke = 0.2) + 
          geom_ribbon(data = fit3, aes(x = w.meandist, ymin = fit - 1 * se.fit, ymax = fit + 1 * se.fit, group = as.factor(mean.w.meandist.lab)), alpha = 0.2) + 
          geom_line(data = fit3, aes(x = w.meandist, y = fit, colour = mean.w.meandist.lab), size = 0.8, alpha = 0.8) + 
          coord_cartesian(ylim = c(-0.5, 1)) + scale_color_brewer(palette = "Set1") + 
          guides(shape = F, alpha = F, fill = F) + 
          labs(x = "Non-breeding range spread (km)", y = NULL, colour = NULL, fill = NULL) + 
          theme_tom() + theme(legend.key.size = unit(2.5, "mm"),
                                           legend.text = element_text(size = 5),
                                           legend.title = element_text(size = 7),
                                           legend.position = c(1,0), legend.justification = c(1,0),
                                           legend.background = element_rect(colour = NA),
                                           axis.text.y = element_blank(),
                                           aspect.ratio = 1)
fig4 <- plot_grid(fig4a, fig4b, nrow = 1, labels = c("a", "b"), label_size = 12, align = "hv")
fig4
## Save
# ggsave("plots/fig4.png", fig4, width = unit(150, "mm"), height = unit(80, "mm"), dpi = 1000, units = "mm")


# FIGURE 5 -------------------------------------------------------------------
## Results of population spread analysis
# Labels for plotting
data.pop$zone.lab <- factor(data.pop$zone)
levels(data.pop$zone.lab) <- c("Northern", "Southern")
data.pop$system.lab <- factor(data.pop$system)
levels(data.pop$system.lab) <- c("Afro-Palearctic", "Neotropic")
data.pop$system.lab <- factor(data.pop$system.lab, levels = levels(data.pop$system.lab)[c(2,1)])

fit2$zone.lab <- factor(fit2$zone)
levels(fit2$zone.lab) <- c("Northern", "Southern")
fit2$system.lab <- factor(fit2$system)
levels(fit2$system.lab) <- c("Afro-Palearctic", "Neotropic")
fit2$system.lab <- factor(fit2$system.lab, levels = levels(fit2$system.lab)[c(2,1)])

# Colours for plotting
hispreadcol <- "#203864"
lospreadcol <- "#B4C7E7"

# Predictions
## Fit3 plot
fig5b <- ggplot() + geom_point(data = data.pop, aes(x = b.lon.rel, y = w.meandist, fill = (w.meandist)), size = 1, alpha = 0.8, shape = 21, col = 1, stroke = 0.2) + 
          geom_hline(data = data.pop, aes(yintercept = mean(w.meandist)), alpha = 0.4) + 
          geom_line(data = fit2, aes(x = b.lon.rel, y = fit))+
          geom_ribbon(data = fit2, aes(x = b.lon.rel, ymax = fit + se.fit * 1, ymin = fit - se.fit * 1), alpha = 0.3)+
          facet_grid(zone.lab ~ system.lab)+
          scale_fill_continuous(low = lospreadcol, high = hispreadcol) + guides(fill = F)+
          scale_x_continuous(limits = c(-60, 60), breaks = c(-50, 0, 50)) + scale_y_continuous(breaks = c(0, 1000, 2000))+
          labs(x = "Relative breeding longitude\n(centered)", y = "Population spread (km)")+
          theme_tom() + theme(aspect.ratio = 1)       

# Histogram data for overlaying on map
h11 <- hist(subset(data.pop, zone == 1 & system == 1)$w.meandist, breaks = seq(0, 2500, by = 500))
h12 <- hist(subset(data.pop, zone == 2 & system == 1)$w.meandist, breaks = seq(0, 2500, by = 500))
h21 <- hist(subset(data.pop, zone == 1 & system == 2)$w.meandist, breaks = seq(0, 2500, by = 500))
h22 <- hist(subset(data.pop, zone == 2 & system == 2)$w.meandist, breaks = seq(0, 2500, by = 500))

h11$lab <- paste(h11$freq, " (", h11$prop, ")", sep = "")
h12$lab <- paste(h12$freq, " (", h12$prop, ")", sep = "")
h21$lab <- paste(h21$freq, " (", h21$prop, ")", sep = "")
h22$lab <- paste(h22$freq, " (", h22$prop, ")", sep = "")

h11 <- data.frame("spread" = h11$breaks[-1]-250, "freq" = h11$counts, "prop" = round(h11$counts / sum(h11$counts), 2))
h12 <- data.frame("spread" = h12$breaks[-1]-250, "freq" = h12$counts, "prop" = round(h12$counts / sum(h12$counts), 2))
h21 <- data.frame("spread" = h21$breaks[-1]-250, "freq" = h21$counts, "prop" = round(h21$counts / sum(h21$counts), 2))
h22 <- data.frame("spread" = h22$breaks[-1]-250, "freq" = h22$counts, "prop" = round(h22$counts / sum(h22$counts), 2))

h11$lab <- paste(h11$freq, " (", h11$prop, ")", sep = "")
h12$lab <- paste(h12$freq, " (", h12$prop, ")", sep = "")
h21$lab <- paste(h21$freq, " (", h21$prop, ")", sep = "")
h22$lab <- paste(h22$freq, " (", h22$prop, ")", sep = "")

# Maps
fig5a <- ggplot() + geom_polygon(data = neo.shp, aes(x = long, y = lat, group = group), fill = "gray70", colour = "gray50", size = 0.1) +
          theme_bw(7) + 
          theme(axis.text = element_blank(), axis.ticks = element_blank()) + 
          labs(x = NULL, y = NULL) +
          geom_hline(aes(yintercept = 12), linetype = 2, alpha = 0.6) +
          geom_segment(data = h21, aes(x = -95, xend = -95 + (spread/111), y = seq(16, 32, 4), yend = seq(16, 32, 4), size = freq), alpha = 0.5) +
          geom_segment(data = h22, aes(x = -75, xend = -75 + (spread/111), y = seq(-8, 8, 4), yend = seq(-8, 8, 4), size = freq), alpha = 0.5) +
          geom_text(data = h21, aes(x = -94 + (spread/111), y = seq(16, 32, 4), label = lab, size = 5, hjust = 0)) + 
          geom_text(data = h22, aes(x = -74 + (spread/111), y = seq(-8, 8 , 4), label = lab, size = 5, hjust = 0)) + 
          guides(size = F) + scale_size_continuous(range = c(0.2, 2.5)) +
          theme(axis.text = element_text(size = 4)) +
          coord_map("mercator", xlim = c(-110, -40), ylim = c(-35, 45))
fig5c <- ggplot() + geom_polygon(data = pal.shp, aes(x = long, y = lat, group = group), fill = "gray70", colour = "gray50", size = 0.1) +
          theme_bw(7) + 
          theme(axis.text = element_blank(), axis.ticks = element_blank()) + 
          labs(x = NULL, y = NULL) + 
          geom_hline(aes(yintercept = 4), linetype = 2, alpha = 0.6) +
          geom_segment(data = h11, aes(x = 5, xend = 5 + (spread/111), y = seq(8, 24, 4), yend = seq(8, 24, 4), size = freq), alpha = 0.5) +
          geom_segment(data = h12, aes(x = 15, xend = 15 + (spread/111), y = seq(-16, 0, 4), yend = seq(-16, 0, 4), size = freq), alpha = 0.5) +
          geom_text(data = h11, aes(x = 6 + (spread/111), y = seq(8  , 24, 4), label =  lab, size = 5, hjust = 0)) + 
          geom_text(data = h12, aes(x = 17 + (spread/111), y = seq(-16, 0 , 4), label = lab, size = 5, hjust = 0)) + 
          guides(size = F) + scale_size_continuous(range = c(0.2, 2.5)) +
          theme(axis.text = element_text(size = 4)) +
          coord_map("mercator", xlim = c(-15, 55), ylim = c(-35, 45))

fig5 <- plot_grid(fig5a, fig5b, fig5c, nrow = 1, rel_widths = c(0.3, 0.4, 0.3), labels = c("a", "b", "c"), label_size = 12)
fig5
# Save
# ggsave("plots/fig5.png", fig5, width = unit(150, "mm"), height = unit(75, "mm"), dpi = 1000, units = "mm")

# GRAPHICAL ABSTRACT ------------------------------------------------------
data <- merge(data, dplyr:::select(data.pop, popid, w.meandist), by = 'popid')
gabstra <- ggplot() + geom_polygon(data = neo.shp, aes(x = long, y = lat, group = group), fill = "black", colour = "black", size = 0.1) +
          coord_map("mercator", xlim = c(-132, -37), ylim = c(-45, 65)) + 
          theme_bw(7) + theme(axis.text = element_blank(), axis.ticks = element_blank(), panel.background = element_rect(fill = "gray15"), panel.grid = element_blank()) + 
          labs(x = NULL, y = NULL) +
          geom_segment(data = subset(data, system == 2), aes(x = blon, y = blat, xend = wlon1, yend = wlat1, col = wlon1), alpha = 0.3, size = 0.4) +
          scale_color_viridis(option = "A") + guides(colour = F)
gabstrb <- ggplot() + geom_polygon(data = pal.shp, aes(x = long, y = lat, group = group), fill = "black", colour = "black", size = 0.1) +
          coord_map("mercator", xlim = c(-25, 70), ylim = c(-45, 65)) + 
          theme_bw(7) + theme(axis.text = element_blank(), axis.ticks = element_blank(), panel.background = element_rect(fill = "gray15"), panel.grid = element_blank()) + 
          labs(x = NULL, y = NULL) +
          geom_segment(data = subset(data, system == 1), aes(x = blon, y = blat, xend = wlon1, yend = wlat1, col = wlon1), alpha = 0.3, size = 0.4) +
          scale_color_viridis(option = "A") + guides(colour = F)
gabstr <- plot_grid(gabstra, gabstrb)
gabstr
# Save
# ggsave("plots/graphical abstract.png", gabstr, width = unit(150, "mm"), height = unit(110, "mm"), dpi = 1000, units = "mm")


